@@ -415,22 +415,29 @@ class Program(object):
                     )
                 )
             # on va donc re-traiter le premier film pour reprendre la diffusion
-            # à |diff| + 10 secondes
-            # (on estime à 10 secondes le temps de traitement)
-            m, s = divmod(diff+10, 60)
+            # à |diff| + 20 secondes
+            # (on estime à 20 secondes le temps de traitement)
+            m, s = divmod(diff+20, 60)
             h, m = divmod(m, 60)
             h_m_s = "%d:%02d:%02d" % (h, m, s)
+            pid = CONFIG['SERVICE:{}'.format(self.service_id)]['pid_video']
+            name = CONFIG['SERVICE:{}'.format(self.service_id)]['name']
+            bitrate = int(
+                CONFIG['SERVICE:{}'.format(self.service_id)]['bitrate']
+                )
+            bitrate = bitrate / 1000
             trim_file = (
                 "/usr/bin/avconv -i {0} -ss {1} -codec copy "
                 "-mpegts_service_id {2} -mpegts_start_pid {3} "
                 "-metadata service_provider='CTV' "
                 "-metadata service_name='{4}' "
-                "-f mpegts -muxrate 2500k -y {5}").format(
+                "-f mpegts -muxrate {5}k -y {6}").format(
                     filepath,
                     h_m_s,
                     self.service_id,
-                    CONFIG['SERVICE:{}'.format(self.service_id)]['pid_video'],
-                    CONFIG['SERVICE:{}'.format(self.service_id)]['name'],
+                    pid,
+                    name,
+                    bitrate,
                     trimmed_file
                     )
             subprocess.call(shlex.split(trim_file))
